@@ -2,10 +2,9 @@ from FreeTAKServer.model.SpecificCoT.SendRoute import SendRoute
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 from FreeTAKServer.model.RestMessages.RestEnumerations import RestEnumerations
-import uuid
 from FreeTAKServer.model.FTSModel.Event import Event as event
 import json as jsonmodule
-from lxml import etree
+from lxml.etree import tostring
 from FreeTAKServer.controllers.serializers.xml_serializer import XmlSerializer
 from FreeTAKServer.controllers.configuration.RestAPIVariables import RestAPIVariables
 from geopy import Nominatim
@@ -20,7 +19,7 @@ class SendRouteController:
         object = SendRoute()
         object.setModelObject(tempObject)
         object.modelObject = self._serializeJsonToModel(object.modelObject, json)
-        object.setXmlString(etree.tostring(XmlSerializer().from_fts_object_to_format(object.modelObject)))
+        object.setXmlString(tostring(XmlSerializer().from_fts_object_to_format(object.modelObject)))
         self.setCoTObject(object)
 
     def _serializeJsonToModel(self, object: event, json):
@@ -28,7 +27,7 @@ class SendRouteController:
             point = object.point
             end = object.detail.getlink()
             if json.getaddress():
-                locator = Nominatim(user_agent=str(uuid.uuid4()))
+                locator = Nominatim(user_agent="myGeocoder")
                 location = locator.geocode(json.getaddress())
                 end.setpoint(f"{location.latitude}, {location.longitude}")
                 # point.setlat(location.latitude)
