@@ -1,6 +1,7 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModel.Checklist import Checklist
 
-class Checklists:
+class Checklists(FTSProtocolObject):
     def __init__(self):
         self.checklist = []
         self.__index = 0
