@@ -3,7 +3,7 @@ from FreeTAKServer.model.FTSModelVariables.DestVariables import DestVariables as
 
 class Dest(FTSProtocolObject):
     def __init__(self, CALLSIGN = vars.other().CALLSIGN):
-        self.callsign = None
+        self.callsign = CALLSIGN
         self.__settercalled = False
         self.__gettercalled = False
         # self.setcallsign(CALLSIGN)
@@ -14,10 +14,16 @@ class Dest(FTSProtocolObject):
 
         return dest
 
-    @staticmethod
-    def geochat(CALLSIGN = vars.geochat().CALLSIGN):
-        dest = Dest()
+    @classmethod
+    def geochat(cls, CALLSIGN = vars.geochat().CALLSIGN):
+        # dest = Dest()
         # dest.setcallsign(CALLSIGN)
+        return cls(CALLSIGN)
+
+    @classmethod
+    def VideoStream(cls):
+        dest = Dest()
+
         return dest
 
     def getcallsign(self):
