@@ -1,6 +1,7 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.MissionNameVariables import MissionNameVariables as vars
 
-class MissionName:
+class MissionName(FTSProtocolObject):
     def __init__(self):
         self.INTAG = None
 
