@@ -1,5 +1,5 @@
 class SubmissionTimeVariables:
     @classmethod
-    def CreateExCheckTemplate(cls):
+    def ExcheckUpdate(cls):
         cls.INTAG = None
         return cls
\ No newline at end of file
